@@ -34,15 +34,18 @@ lang_spec_t langs[] = {
     { "json", { "json" } },
     { "jsp", { "jsp", "jspx", "jhtm", "jhtml" } },
     { "less", { "less" } },
+    { "liquid", { "liquid" } },
     { "lisp", { "lisp", "lsp" } },
     { "lua", { "lua" } },
     { "m4", { "m4" } },
     { "make", { "Makefiles", "mk", "mak" } },
+    { "markdown", { "markdown", "mdown", "mdwn", "mkdn", "mkd", "md" } },
     { "mason", { "mas", "mhtml", "mpl", "mtxt" } },
     { "matlab", { "m" } },
+    { "mercury", { "m", "moo" } },
     { "objc", { "m", "h" } },
     { "objcpp", { "mm", "h" } },
-    { "ocaml", { "ml", "mli" } },
+    { "ocaml", { "ml", "mli", "mll", "mly" } },
     { "octave", { "m" } },
     { "parrot", { "pir", "pasm", "pmc", "ops", "pod", "pg", "tg" } },
     { "perl", { "pl", "pm", "pm6", "pod", "t" } },
