@@ -36,6 +36,8 @@ Output Options:\n\
   -B --before [LINES]     Print lines before match (Default: 2)\n\
      --[no]break          Print newlines between matches in different files\n\
                           (Enabled by default)\n\
+  -c --count              Only print the number of matches in each file.\n\
+                          (This often differs from the number of matching lines)\n\
      --[no]color          Print color codes in results (Enabled by default)\n\
      --color-line-number  Color codes for line numbers (Default: 1;33)\n\
      --color-match        Color codes for result match numbers (Default: 30;43)\n\
@@ -50,8 +52,8 @@ Output Options:\n\
                           (don't print the matching lines)\n\
   -L --files-without-matches\n\
                           Only print filenames that don't contain matches\n\
-     --null               Follow filename (-l|-L) with null for 'xargs -0'\n\
      --no-numbers         Don't print line numbers\n\
+  -o --only-matching      Prints only the matching part of the lines\n\
      --print-long-lines   Print matches on very long lines (Default: >2k characters)\n\
      --passthrough        When searching a stream, print all lines even if they\n\
                           don't match\n\
@@ -59,6 +61,7 @@ Output Options:\n\
      --stats              Print stats (files scanned, time taken, etc.)\n\
      --vimgrep            Print results like vim's :vimgrep /pattern/g would\n\
                           (it reports every match on the line)\n\
+  -0 --null --print0      Separate filenames with null (for 'xargs -0')\n\
 \n\
 Search Options:\n\
   -a --all-types          Search all files (doesn't include hidden files\n\
@@ -66,6 +69,7 @@ Search Options:\n\
   -D --debug              Ridiculous debugging (probably not useful)\n\
      --depth NUM          Search up to NUM directories deep (Default: 25)\n\
   -f --follow             Follow symlinks\n\
+  -F --fixed-strings      Alias for --literal for compatibility with grep\n\
   -G --file-search-regex  PATTERN Limit search to filenames matching PATTERN\n\
      --hidden             Search hidden files (obeys .*ignore files)\n\
   -i --ignore-case        Match case insensitively\n\
@@ -104,14 +108,15 @@ void print_version(void) {
 
 void init_options(void) {
     memset(&opts, 0, sizeof(opts));
-    opts.casing = CASE_SMART;
+    opts.casing = CASE_DEFAULT;
 #ifdef _WIN32
     opts.color = (getenv("ANSICON") || getenv("CMDER_ROOT")) ? TRUE : FALSE;
 #else
     opts.color = TRUE;
 #endif
-    opts.max_matches_per_file = 10000;
+    opts.max_matches_per_file = 0;
     opts.max_search_depth = DEFAULT_MAX_SEARCH_DEPTH;
+    opts.path_sep = '\n';
     opts.print_break = TRUE;
     opts.print_path = PATH_PRINT_DEFAULT;
     opts.print_line_numbers = TRUE;
@@ -191,11 +196,13 @@ void parse_options(int argc, char **argv, char **base_paths[], char **paths[]) {
         { "color-path", required_argument, NULL, 0 },
         { "column", no_argument, &opts.column, 1 },
         { "context", optional_argument, NULL, 'C' },
+        { "count", no_argument, NULL, 'c'},
         { "debug", no_argument, NULL, 'D' },
         { "depth", required_argument, NULL, 0 },
         { "file-search-regex", required_argument, NULL, 'G' },
         { "files-with-matches", no_argument, NULL, 'l' },
         { "files-without-matches", no_argument, NULL, 'L' },
+        { "fixed-strings", no_argument, NULL, 'F' },
         { "follow", no_argument, &opts.follow_symlinks, 1 },
         { "group", no_argument, &group, 1 },
         { "heading", no_argument, &opts.print_path, PATH_PRINT_TOP },
@@ -218,12 +225,14 @@ void parse_options(int argc, char **argv, char **base_paths[], char **paths[]) {
         { "nogroup", no_argument, &group, 0 },
         { "noheading", no_argument, &opts.print_path, PATH_PRINT_EACH_LINE },
         { "nopager", no_argument, NULL, 0 },
-        { "null", no_argument, &opts.null_follows_filename, 1 },
+        { "null", no_argument, NULL, '0' },
+        { "only-matching", no_argument, NULL, 'o' },
         { "pager", required_argument, NULL, 0 },
         { "parallel", no_argument, &opts.parallel, 1 },
         { "passthrough", no_argument, &opts.passthrough, 1 },
         { "passthru", no_argument, &opts.passthrough, 1 },
         { "path-to-agignore", required_argument, NULL, 'p' },
+        { "print0", no_argument, NULL, '0'},
         { "print-long-lines", no_argument, &opts.print_long_lines, 1 },
         { "recurse", no_argument, NULL, 'r' },
         { "search-binary", no_argument, &opts.search_binary_files, 1 },
@@ -261,7 +270,7 @@ void parse_options(int argc, char **argv, char **base_paths[], char **paths[]) {
 
     rv = fstat(fileno(stdin), &statbuf);
     if (rv == 0) {
-        if (S_ISFIFO(statbuf.st_mode)) {
+        if (S_ISFIFO(statbuf.st_mode) || S_ISREG(statbuf.st_mode)) {
             opts.search_stream = 1;
         }
     }
@@ -282,7 +291,8 @@ void parse_options(int argc, char **argv, char **base_paths[], char **paths[]) {
         opts.stdout_inode = statbuf.st_ino;
     }
 
-    while ((ch = getopt_long(argc, argv, "A:aB:C:DG:g:fHhiLlm:np:QRrSsvVtuUwz", longopts, &opt_index)) != -1) {
+    int pcre_opts = 0;
+    while ((ch = getopt_long(argc, argv, "A:aB:C:cDG:g:FfHhiLlm:nop:QRrSsvVtuUwz0", longopts, &opt_index)) != -1) {
         switch (ch) {
             case 'A':
                 if (optarg) {
@@ -324,6 +334,10 @@ void parse_options(int argc, char **argv, char **base_paths[], char **paths[]) {
                     opts.context = DEFAULT_CONTEXT_LEN;
                 }
                 break;
+            case 'c':
+                opts.print_count = 1;
+                opts.print_filename_only = 1;
+                break;
             case 'D':
                 set_log_level(LOG_LEVEL_DEBUG);
                 break;
@@ -335,8 +349,13 @@ void parse_options(int argc, char **argv, char **base_paths[], char **paths[]) {
                 opts.match_files = 1;
             /* Fall through and build regex */
             case 'G':
-                compile_study(&opts.file_search_regex, &opts.file_search_regex_extra, optarg, opts.casing & PCRE_CASELESS, 0);
-                opts.casing = CASE_SENSITIVE;
+                if (opts.casing == CASE_DEFAULT) {
+                    opts.casing = CASE_SENSITIVE;
+                }
+                if (opts.casing != CASE_SENSITIVE) {
+                    pcre_opts |= PCRE_CASELESS;
+                }
+                compile_study(&opts.file_search_regex, &opts.file_search_regex_extra, optarg, pcre_opts, 0);
                 break;
             case 'H':
                 opts.print_path = PATH_PRINT_TOP;
@@ -363,6 +382,10 @@ void parse_options(int argc, char **argv, char **base_paths[], char **paths[]) {
             case 'p':
                 opts.path_to_agignore = optarg;
                 break;
+            case 'o':
+                opts.only_matching = 1;
+                break;
+            case 'F':
             case 'Q':
                 opts.literal = 1;
                 break;
@@ -399,6 +422,9 @@ void parse_options(int argc, char **argv, char **base_paths[], char **paths[]) {
             case 'z':
                 opts.search_zip_files = 1;
                 break;
+            case '0':
+                opts.path_sep = '\0';
+                break;
             case 0: /* Long option */
                 if (strcmp(longopts[opt_index].name, "ackmate-dir-filter") == 0) {
                     compile_study(&opts.ackmate_dir_filter, &opts.ackmate_dir_filter_extra, optarg, 0, 0);
@@ -472,6 +498,10 @@ void parse_options(int argc, char **argv, char **base_paths[], char **paths[]) {
     argc -= optind;
     argv += optind;
 
+    if (opts.casing == CASE_DEFAULT) {
+        opts.casing = CASE_SMART;
+    }
+
     if (opts.pager) {
         out_fd = popen(opts.pager, "w");
         if (!out_fd) {
@@ -522,9 +552,9 @@ void parse_options(int argc, char **argv, char **base_paths[], char **paths[]) {
         char *gitconfig_res = NULL;
 
 #ifdef _WIN32
-        gitconfig_file = popen("git config -z --get core.excludesfile 2>NUL", "r");
+        gitconfig_file = popen("git config -z --path --get core.excludesfile 2>NUL", "r");
 #else
-        gitconfig_file = popen("git config -z --get core.excludesfile 2>/dev/null", "r");
+        gitconfig_file = popen("git config -z --path --get core.excludesfile 2>/dev/null", "r");
 #endif
         if (gitconfig_file != NULL) {
             do {
@@ -532,6 +562,7 @@ void parse_options(int argc, char **argv, char **base_paths[], char **paths[]) {
                 buf_len += fread(gitconfig_res + buf_len, 1, 64, gitconfig_file);
             } while (!feof(gitconfig_file) && buf_len > 0 && buf_len % 64 == 0);
             gitconfig_res[buf_len] = '\0';
+            log_debug("Found user's global Git excludesfile: %s", gitconfig_res);
             load_ignore_patterns(root_ignores, gitconfig_res);
             free(gitconfig_res);
             pclose(gitconfig_file);
